@@ -9,14 +9,16 @@ from schemey.json_schema_context import JsonSchemaContext
 
 
 class IntegerSchemaLoader(SchemaLoaderABC):
-
-    def load(self, item: ExternalItemType, json_context: JsonSchemaContext) -> Optional[SchemaABC]:
-        if item.get('type') != 'integer':
+    def load(
+        self, item: ExternalItemType, json_context: JsonSchemaContext
+    ) -> Optional[SchemaABC]:
+        if item.get("type") != "integer":
             return None
         loaded = IntegerSchema(
-            minimum=item.get('minimum'),
-            exclusive_minimum=item.get('exclusiveMinimum'),
-            maximum=item.get('maximum'),
-            exclusive_maximum=item.get('exclusiveMaximum')
+            minimum=item.get("minimum"),
+            exclusive_minimum=item.get("exclusiveMinimum"),
+            maximum=item.get("maximum"),
+            exclusive_maximum=item.get("exclusiveMaximum"),
+            description=item.get("description"),
         )
         return loaded
