@@ -9,14 +9,16 @@ from schemey.number_schema import NumberSchema
 
 
 class NumberSchemaLoader(SchemaLoaderABC):
-
-    def load(self, item: ExternalItemType, json_context: JsonSchemaContext) -> Optional[SchemaABC]:
-        if item.get('type') != 'number':
+    def load(
+        self, item: ExternalItemType, json_context: JsonSchemaContext
+    ) -> Optional[SchemaABC]:
+        if item.get("type") != "number":
             return None
         loaded = NumberSchema(
-            minimum=item.get('minimum'),
-            exclusive_minimum=item.get('exclusiveMinimum'),
-            maximum=item.get('maximum'),
-            exclusive_maximum=item.get('exclusiveMaximum')
+            minimum=item.get("minimum"),
+            exclusive_minimum=item.get("exclusiveMinimum"),
+            maximum=item.get("maximum"),
+            exclusive_maximum=item.get("exclusiveMaximum"),
+            description=item.get("description"),
         )
         return loaded
