@@ -8,11 +8,12 @@ from schemey.loader.schema_loader_abc import SchemaLoaderABC
 
 
 class RefSchemaLoader(SchemaLoaderABC):
-
-    def load(self, item: ExternalItemType, json_context: JsonSchemaContext) -> Optional[SchemaABC]:
-        if '$ref' not in item:
+    def load(
+        self, item: ExternalItemType, json_context: JsonSchemaContext
+    ) -> Optional[SchemaABC]:
+        if "$ref" not in item:
             return None
-        ref = item['$ref']
+        ref = item["$ref"]
         if not ref.startswith(json_context.defs_path):
             return None  # We don't support loading from anywhere in the document for now...
         ref = ref[len(json_context.defs_path):]
